=========================
Caching model evaluations
=========================

.. todo::

   There is obviously a *lot* more text to go here.

Sherpa contains a rudimentary system for cacheing the results
of a model evaluation. It is related to the
:py:func:`~sherpa.models.model.modelCacher1d`
function decorator.

